@@ -6,6 +6,7 @@
 #' @param add_effect hhh
 #' @param dom_effect = NULL,
 #' @param epi_effect kkkk
+#' @param epi_interaction = NULL,
 #' @param ntraits hhh
 #' @param cor hhh
 #' @param architecture hhh
@@ -28,6 +29,7 @@ base_line_multi_traits <-
            add_effect = NULL,
            dom_effect = NULL,
            epi_effect = NULL,
+           epi_interaction = NULL,
            ntraits = NULL,
            cor = NULL,
            architecture = NULL,
@@ -79,6 +81,7 @@ base_line_multi_traits <-
                 add_effect = add_effect[[j]],
                 dom_effect = dom_effect[[j]],
                 epi_effect = epi_effect[[j]],
+                epi_interaction = epi_interaction,
                 ntraits = ntraits,
                 add = add,
                 dom = dom,
@@ -104,22 +107,10 @@ base_line_multi_traits <-
           meang <- apply(genetic_value, 2, mean)
           genetic_s <- apply(genetic_value, 2, scale)
           cg <- cov(genetic_s)
-          if (!lqmm::is.positive.definite(cg)) {
-            if (verbose)
-              cat(
-                "Using lqmm::make.positive.definite() to make genetic correlation positive definite!\n"
-              )
-            cg <- lqmm::make.positive.definite(cg)
-          }
+          cg <- make_pd(cg, verbose = verbose)
           L <- t(chol(cg))
           G_white <- t(solve(L) %*% t(genetic_s))
-          if (!lqmm::is.positive.definite(cor)) {
-            if (verbose)
-              cat(
-                "cor matrix not positive definite! Applying lqmm::make.positive.definite() \n"
-              )
-            cor <- lqmm::make.positive.definite(cor)
-          }
+          cor <- make_pd(cor, verbose = verbose)
           L <- t(chol(cor))
           traits <- t(L %*% t(G_white))
           rownames(traits) <- rownames
@@ -165,6 +156,7 @@ base_line_multi_traits <-
                 add_effect = add_effect[[j]],
                 dom_effect = dom_effect[[j]],
                 epi_effect = epi_effect[[j]],
+                epi_interaction = epi_interaction,
                 ntraits = ntraits,
                 add = add,
                 dom = dom,
@@ -190,23 +182,10 @@ base_line_multi_traits <-
           meang <- apply(genetic_value, 2, mean)
           genetic_s <- apply(genetic_value, 2, scale)
           cg <- cov(genetic_s)
-          if (!lqmm::is.positive.definite(cg)) {
-            if (verbose)
-              cat(
-                "Using lqmm::make.positive.definite() to make genetic correlation positive definite!\n"
-              )
-            cg <- lqmm::make.positive.definite(cg)
-          }
+          cg <- make_pd(cg, verbose = verbose)
           L <- t(chol(cg))
           G_white <- t(solve(L) %*% t(genetic_s))
-          if (!lqmm::is.positive.definite(cor)) {
-            if (verbose)
-              cat(
-                "cor matrix not positive definite! Applying lqmm::make.positive.definite \n"
-              )
-            cor <-
-              lqmm::make.positive.definite(cor)
-          }
+          cor <- make_pd(cor, verbose = verbose)
           L <- t(chol(cor))
           traits <- t(L %*% t(G_white))
           rownames(traits) <- rownames
@@ -252,6 +231,7 @@ base_line_multi_traits <-
                 add_effect = add_effect[[i]],
                 dom_effect = dom_effect[[i]],
                 epi_effect = epi_effect[[i]],
+                epi_interaction = epi_interaction,
                 ntraits = ntraits,
                 add = add,
                 dom = dom,
@@ -299,6 +279,7 @@ base_line_multi_traits <-
                 add_effect = add_effect[[i]],
                 dom_effect = dom_effect[[i]],
                 epi_effect = epi_effect[[i]],
+                epi_interaction = epi_interaction,
                 ntraits = ntraits,
                 add = add,
                 dom = dom,
